@@ -2,17 +2,40 @@ import sys
 from datetime import datetime
 import logging
 from abc import abstractmethod, ABCMeta
+import os
+
+_LEVEL2TXT = {
+    0: "Not set",
+    10: "DEBUG",
+    20: "INFO",
+    30: "WARNING",
+    40: "ERROR",
+    50: "CRITICAL",
+}
+
+_TXT2LEVEL = {v: k for k, v in _LEVEL2TXT.items()}
 
 
 class LoggerGeneratorBase(metaclass=ABCMeta):
-    @abstractmethod
     def __init__(self):
-        pass
+        self._is_generated = False
+        self._LOG_FOLDER = "./"
+        self._log = None
 
     @abstractmethod
     def __call__(self) -> logging.RootLogger:
         pass
 
+    def get_level(self) -> str:
+        global _LEVEL2TXT
+        assert self._is_generated
+        return _LEVEL2TXT[self._log.level]
+
+    def set_level(self, level: str) -> str:
+        global _TXT2LEVEL
+        assert level in _TXT2LEVEL
+        self._log.setLevel(_TXT2LEVEL[level])
+
 
 class LoggerGenerator(LoggerGeneratorBase):
     """
@@ -23,8 +46,14 @@ class LoggerGenerator(LoggerGeneratorBase):
         >>> log.info("...")
     """
 
-    def __init__(self):
-        self._is_generated = False
+    def _init_(self):
+        super(LoggerGenerator, self).__init__()
+
+    def set_folder(self, log_folder: str):
+        assert os.path.exists(log_folder)
+        self._LOG_FOLDER = log_folder
+        if not self._LOG_FOLDER[-1] == "/":
+            self._LOG_FOLDER += "/"
 
     def _generate_log(self):
         self._is_gegerated = True
@@ -35,23 +64,23 @@ class LoggerGenerator(LoggerGeneratorBase):
         hour = str(now.hour).zfill(2)
         minute = str(now.minute).zfill(2)
         second = str(now.second).zfill(2)
-        filename = f"{year}{month}{day}-{hour}{minute}{second}.log"
-        self.log = logging.getLogger(__name__)
-        self.log.setLevel(logging.DEBUG)
+        filename = f"{self._LOG_FOLDER}{year}{month}{day}-{hour}{minute}{second}.log"
+        self._log = logging.getLogger(__name__)
+        self._log.setLevel(logging.DEBUG)
         fh = logging.FileHandler(filename)
         sh = logging.StreamHandler(sys.stdout)
         sh.setLevel(logging.DEBUG)
         fmt = logging.Formatter("%(asctime)s - %(levelname)s (%(filename)s) : %(message)s")
         fh.setFormatter(fmt)
         sh.setFormatter(fmt)
-        self.log.addHandler(fh)
-        self.log.addHandler(sh) 
+        self._log.addHandler(fh)
+        self._log.addHandler(sh) 
 
     def __call__(self, g: dict) -> logging.RootLogger:
         if not self._is_generated:
             self._generate_log()
 
-        g["log"] = self.log
+        g["log"] = self._log
 
 
 logger_gen = LoggerGenerator()
